@@ -1,3 +1,4 @@
+import os
 from pathlib import Path
 
 import pkg_resources
@@ -26,5 +27,5 @@ class BackupUtilsConfig(AppConfig):
 
     if BACKUP_DIRS:
         for each in BACKUP_DIRS:
-            if Path(each).is_absolute():
-                raise Exception(f"BACKUP_DIRS path {each} needs to be relative to BASE_DIR ")
+            if not Path(os.path.commonprefix([Path(each), Path(settings.BASE_DIR)])) == Path(settings.BASE_DIR):
+                raise Exception(f"BACKUP_DIRS path {each} needs to be relative to settings.BASE_DIR ")
