@@ -12,9 +12,6 @@ class UtilsBaseException(Exception):
         super().__init__(message + f"\n{output}")
 
 
-class BackupNotFound(UtilsBaseException):
-    pass
-
 
 class CreateException(UtilsBaseException):
     pass
@@ -30,3 +27,7 @@ class UnittestFailed(UtilsBaseException):
 
 class MigrationNotFound(Exception):
     pass
+
+
+class BackupNotFound(Exception):
+    pass
\ No newline at end of file
