@@ -30,12 +30,19 @@ def get_backup_name(filepath, hostname=None, projectname=None, all=False):
         projectname = BackupUtilsConfig.PROJECT_NAME
 
     logger.debug(f"get_backup_name({filepath}, hostname={hostname}, projectname={projectname}, all={all})")
+    logger.debug(f"file name: " + str(Path(filepath).name))
     splits = str(Path(filepath).name).split("_")
     logger.debug(f"splitted path: {splits}")
 
-    if len(splits) == 4:
+    if len(splits) >= 4:
         splits_hostname = splits[0]
-        splits_project = splits[1]
+        splits_project = splits[1:-2]
+        if not isinstance(splits_project, str):
+            proj = ""
+            for each in splits_project:
+                proj += each + "_"
+            splits_project = proj[:-1]
+            logger.debug("project from path: " + str(splits_project))
 
         if all:
             if str(filepath).endswith(".tar.gz") or str(filepath).endswith(".tar"):
